@@ -136,31 +136,33 @@ import org.apache.commons.text.matcher.StringMatcherFactory;
  *
  * <h2>Using Interpolation</h2>
  * <p>
- * The default interpolator let's you use string lookups like:
+ * The default interpolator lets you use string lookups like:
  * </p>
  *
  * <pre>
  * final StringSubstitutor interpolator = StringSubstitutor.createInterpolator();
- * interpolator.setEnableSubstitutionInVariables(true); // Allows for nested $'s.
- * final String text = interpolator.replace("Base64 Decoder:        ${base64Decoder:SGVsbG9Xb3JsZCE=}\n"
+ * final String text = interpolator.replace(
+ *       "Base64 Decoder:        ${base64Decoder:SGVsbG9Xb3JsZCE=}\n"
  *     + "Base64 Encoder:        ${base64Encoder:HelloWorld!}\n"
  *     + "Java Constant:         ${const:java.awt.event.KeyEvent.VK_ESCAPE}\n"
- *     + "Date:                  ${date:yyyy-MM-dd}\n" + "DNS:                   ${dns:address|apache.org}\n"
+ *     + "Date:                  ${date:yyyy-MM-dd}\n"
  *     + "Environment Variable:  ${env:USERNAME}\n"
  *     + "File Content:          ${file:UTF-8:src/test/resources/document.properties}\n"
- *     + "Java:                  ${java:version}\n" + "Localhost:             ${localhost:canonical-name}\n"
+ *     + "Java:                  ${java:version}\n"
+ *     + "Localhost:             ${localhost:canonical-name}\n"
  *     + "Properties File:       ${properties:src/test/resources/document.properties::mykey}\n"
- *     + "Resource Bundle:       ${resourceBundle:org.example.testResourceBundleLookup:mykey}\n"
- *     + "Script:                ${script:javascript:3 + 4}\n" + "System Property:       ${sys:user.dir}\n"
+ *     + "Resource Bundle:       ${resourceBundle:org.apache.commons.text.example.testResourceBundleLookup:mykey}\n"
+ *     + "System Property:       ${sys:user.dir}\n"
  *     + "URL Decoder:           ${urlDecoder:Hello%20World%21}\n"
  *     + "URL Encoder:           ${urlEncoder:Hello World!}\n"
- *     + "URL Content (HTTP):    ${url:UTF-8:http://www.apache.org}\n"
- *     + "URL Content (HTTPS):   ${url:UTF-8:https://www.apache.org}\n"
- *     + "URL Content (File):    ${url:UTF-8:file:///${sys:user.dir}/src/test/resources/document.properties}\n"
  *     + "XML XPath:             ${xml:src/test/resources/document.xml:/root/path/to/node}\n");
  * </pre>
  * <p>
- * For documentation of each lookup, see {@link StringLookupFactory}.
+ * For documentation and a full list of available lookups, see {@link StringLookupFactory}.
+ * </p>
+ * <p><strong>NOTE:</strong> The list of lookups available by default in {@link #createInterpolator()} changed
+ * in version {@code 1.10.0}. See the {@link StringLookupFactory} documentation for details and an explanation
+ * on how to reproduce the previous functionality.
  * </p>
  *
  * <h2>Using Recursive Variable Replacement</h2>
@@ -231,7 +233,6 @@ public class StringSubstitutor {
         public final int lengthChange;
 
         private Result(final boolean altered, final int lengthChange) {
-            super();
             this.altered = altered;
             this.lengthChange = lengthChange;
         }
@@ -288,14 +289,86 @@ public class StringSubstitutor {
      * Creates a new instance using the interpolator string lookup
      * {@link StringLookupFactory#interpolatorStringLookup()}.
      * <p>
-     * This StringSubstitutor lets you perform substituions like:
+     * This StringSubstitutor lets you perform substitutions like:
      * </p>
      *
      * <pre>
      * StringSubstitutor.createInterpolator().replace(
-     *   "OS name: ${sys:os.name}, " + "3 + 4 = ${script:javascript:3 + 4}");
+     *   "OS name: ${sys:os.name}, user: ${env:USER}");
      * </pre>
      *
+     * <p>The table below lists the lookups available by default in the returned instance. These
+     * may be modified through the use of the {@value StringLookupFactory#DEFAULT_STRING_LOOKUPS_PROPERTY}
+     * system property, as described in the {@link StringLookupFactory} documentation.</p>
+     *
+     * <p><strong>NOTE:</strong> The list of lookups available by default changed in version {@code 1.10.0}.
+     * Configuration via system property (as mentioned above) may be necessary to reproduce previous functionality.
+     * </p>
+     *
+     * <table>
+     * <caption>Default Lookups</caption>
+     * <tr>
+     * <th>Key</th>
+     * <th>Lookup</th>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_BASE64_DECODER}</td>
+     * <td>{@link StringLookupFactory#base64DecoderStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_BASE64_ENCODER}</td>
+     * <td>{@link StringLookupFactory#base64EncoderStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_CONST}</td>
+     * <td>{@link StringLookupFactory#constantStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_DATE}</td>
+     * <td>{@link StringLookupFactory#dateStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_ENV}</td>
+     * <td>{@link StringLookupFactory#environmentVariableStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_FILE}</td>
+     * <td>{@link StringLookupFactory#fileStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_JAVA}</td>
+     * <td>{@link StringLookupFactory#javaPlatformStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_LOCALHOST}</td>
+     * <td>{@link StringLookupFactory#localHostStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_PROPERTIES}</td>
+     * <td>{@link StringLookupFactory#propertiesStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_RESOURCE_BUNDLE}</td>
+     * <td>{@link StringLookupFactory#resourceBundleStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_SYS}</td>
+     * <td>{@link StringLookupFactory#systemPropertyStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_URL_DECODER}</td>
+     * <td>{@link StringLookupFactory#urlDecoderStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_URL_ENCODER}</td>
+     * <td>{@link StringLookupFactory#urlEncoderStringLookup()}</td>
+     * </tr>
+     * <tr>
+     * <td>{@value StringLookupFactory#KEY_XML}</td>
+     * <td>{@link StringLookupFactory#xmlStringLookup()}</td>
+     * </tr>
+     * </table>
+     *
      * @return a new instance using the interpolator string lookup.
      * @see StringLookupFactory#interpolatorStringLookup()
      * @since 1.8
@@ -351,7 +424,7 @@ public class StringSubstitutor {
         final Map<String, String> valueMap = new HashMap<>();
         final Enumeration<?> propNames = valueProperties.propertyNames();
         while (propNames.hasMoreElements()) {
-            final String propName = (String) propNames.nextElement();
+            final String propName = String.valueOf(propNames.nextElement());
             final String propValue = valueProperties.getProperty(propName);
             valueMap.put(propName, propValue);
         }
@@ -559,7 +632,7 @@ public class StringSubstitutor {
     /**
      * Creates a new instance based on the given StringSubstitutor.
      *
-     * @param other The StringSubstitutor is use as the source.
+     * @param other The StringSubstitutor used as the source.
      * @since 1.9
      */
     public StringSubstitutor(final StringSubstitutor other) {
@@ -735,6 +808,10 @@ public class StringSubstitutor {
      * @param length the length within the array to be processed, must be valid
      * @return The result of the replace operation
      * @throws IllegalArgumentException if variable is not found when its allowed to throw exception
+     * @throws StringIndexOutOfBoundsException if {@code offset} is not in the
+     *  range {@code 0 <= offset <= chars.length}
+     * @throws StringIndexOutOfBoundsException if {@code length < 0}
+     * @throws StringIndexOutOfBoundsException if {@code offset + length > chars.length}
      */
     public String replace(final char[] source, final int offset, final int length) {
         if (source == null) {
@@ -832,6 +909,10 @@ public class StringSubstitutor {
      * @param length the length within the source to be processed, must be valid
      * @return The result of the replace operation
      * @throws IllegalArgumentException if variable is not found when its allowed to throw exception
+     * @throws StringIndexOutOfBoundsException if {@code offset} is not in the
+     *  range {@code 0 <= offset <= source.length()}
+     * @throws StringIndexOutOfBoundsException if {@code length < 0}
+     * @throws StringIndexOutOfBoundsException if {@code offset + length > source.length()}
      */
     public String replace(final String source, final int offset, final int length) {
         if (source == null) {
@@ -1157,7 +1238,7 @@ public class StringSubstitutor {
      * @return this, to enable chaining
      */
     public StringSubstitutor setValueDelimiter(final String valueDelimiter) {
-        if (valueDelimiter == null || valueDelimiter.length() == 0) {
+        if (valueDelimiter == null || valueDelimiter.isEmpty()) {
             setValueDelimiterMatcher(null);
             return this;
         }
@@ -1317,7 +1398,7 @@ public class StringSubstitutor {
      * @param length the length within the builder to be processed, must be valid
      * @param priorVariables the stack keeping track of the replaced variables, may be null
      * @return The result.
-     * @throws IllegalArgumentException if variable is not found when its allowed to throw exception
+     * @throws IllegalArgumentException if variable is not found and <pre>isEnableUndefinedVariableException()==true</pre>
      * @since 1.9
      */
     private Result substitute(final TextStringBuilder builder, final int offset, final int length,
