@@ -19,8 +19,7 @@ package org.apache.commons.text;
 import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.assertj.core.api.Assertions.assertThatIllegalArgumentException;
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 
 import java.text.DateFormat;
 import java.text.FieldPosition;
@@ -61,7 +60,6 @@ public class ExtendedMessageFormatTest {
         }
     }
 
-    // ------------------------ Test Format Factories ---------------
     /**
      * {@link FormatFactory} implementation for lower case format.
      */
@@ -263,7 +261,7 @@ public class ExtendedMessageFormatTest {
     @Test
     public void testBuiltInChoiceFormat() {
         final Object[] values = new Number[] {1, Double.valueOf("2.2"), Double.valueOf("1234.5")};
-        String choicePattern = null;
+        String choicePattern;
         final Locale[] availableLocales = NumberFormat.getAvailableLocales();
 
         choicePattern = "{0,choice,1#One|2#Two|3#Many {0,number}}";
@@ -284,7 +282,7 @@ public class ExtendedMessageFormatTest {
     public void testBuiltInDateTimeFormat() {
         final Calendar cal = Calendar.getInstance();
         cal.set(2007, Calendar.JANUARY, 23, 18, 33, 5);
-        final Object[] args = new Object[] {cal.getTime()};
+        final Object[] args = {cal.getTime()};
         final Locale[] availableLocales = DateFormat.getAvailableLocales();
 
         checkBuiltInFormat("1: {0,date,short}",    args, availableLocales);
@@ -306,7 +304,7 @@ public class ExtendedMessageFormatTest {
      */
     @Test
     public void testBuiltInNumberFormat() {
-        final Object[] args = new Object[] {Double.valueOf("6543.21")};
+        final Object[] args = {Double.valueOf("6543.21")};
         final Locale[] availableLocales = NumberFormat.getAvailableLocales();
         checkBuiltInFormat("1: {0,number}",           args, availableLocales);
         checkBuiltInFormat("2: {0,number,integer}",   args, availableLocales);
@@ -336,7 +334,7 @@ public class ExtendedMessageFormatTest {
                 new ExtendedMessageFormat("Unterminated format element at position ", map);
 
         assertEquals("Unterminated format element at position ", extendedMessageFormatTwo.toPattern());
-        assertFalse(extendedMessageFormat.equals(extendedMessageFormatTwo));
+        assertNotEquals(extendedMessageFormat, extendedMessageFormatTwo);
     }
 
     /**
@@ -362,38 +360,38 @@ public class ExtendedMessageFormatTest {
         final String pattern = "Pattern: {0,testfmt}";
         final ExtendedMessageFormat emf = new ExtendedMessageFormat(pattern, Locale.US, fmtRegistry);
 
-        ExtendedMessageFormat other = null;
+        ExtendedMessageFormat other;
 
         // Same object
-        assertTrue(emf.equals(emf), "same, equals()");
+        assertEquals(emf, emf, "same, equals()");
         assertEquals(emf.hashCode(), emf.hashCode(), "same, hashcode()");
 
-        assertFalse(emf.equals(null), "null, equals");
+        assertNotEquals(null, emf, "null, equals");
 
         // Equal Object
         other = new ExtendedMessageFormat(pattern, Locale.US, fmtRegistry);
-        assertTrue(emf.equals(other), "equal, equals()");
-        assertTrue(emf.hashCode() == other.hashCode(), "equal, hashcode()");
+        assertEquals(emf, other, "equal, equals()");
+        assertEquals(emf.hashCode(), other.hashCode(), "equal, hashcode()");
 
         // Different Class
         other = new OtherExtendedMessageFormat(pattern, Locale.US, fmtRegistry);
-        assertFalse(emf.equals(other), "class, equals()");
-        assertTrue(emf.hashCode() == other.hashCode(), "class, hashcode()"); // same hashcode
+        assertNotEquals(emf, other, "class, equals()");
+        assertEquals(emf.hashCode(), other.hashCode(), "class, hashcode()"); // same hashcode
 
         // Different pattern
         other = new ExtendedMessageFormat("X" + pattern, Locale.US, fmtRegistry);
-        assertFalse(emf.equals(other), "pattern, equals()");
-        assertFalse(emf.hashCode() == other.hashCode(), "pattern, hashcode()");
+        assertNotEquals(emf, other, "pattern, equals()");
+        assertNotEquals(emf.hashCode(), other.hashCode(), "pattern, hashcode()");
 
         // Different registry
         other = new ExtendedMessageFormat(pattern, Locale.US, otherRegistry);
-        assertFalse(emf.equals(other), "registry, equals()");
-        assertFalse(emf.hashCode() == other.hashCode(), "registry, hashcode()");
+        assertNotEquals(emf, other, "registry, equals()");
+        assertNotEquals(emf.hashCode(), other.hashCode(), "registry, hashcode()");
 
         // Different Locale
         other = new ExtendedMessageFormat(pattern, Locale.FRANCE, fmtRegistry);
-        assertFalse(emf.equals(other), "locale, equals()");
-        assertTrue(emf.hashCode() == other.hashCode(), "locale, hashcode()"); // same hashcode
+        assertNotEquals(emf, other, "locale, equals()");
+        assertEquals(emf.hashCode(), other.hashCode(), "locale, hashcode()"); // same hashcode
     }
 
     /**
@@ -429,13 +427,12 @@ public class ExtendedMessageFormatTest {
     public void testExtendedAndBuiltInFormats() {
         final Calendar cal = Calendar.getInstance();
         cal.set(2007, Calendar.JANUARY, 23, 18, 33, 5);
-        final Object[] args = new Object[] {"John Doe", cal.getTime(), Double.valueOf("12345.67")};
+        final Object[] args = {"John Doe", cal.getTime(), Double.valueOf("12345.67")};
         final String builtinsPattern = "DOB: {1,date,short} Salary: {2,number,currency}";
         final String extendedPattern = "Name: {0,upper} ";
         final String pattern = extendedPattern + builtinsPattern;
 
-        final HashSet<Locale> testLocales = new HashSet<>();
-        testLocales.addAll(Arrays.asList(DateFormat.getAvailableLocales()));
+        final HashSet<Locale> testLocales = new HashSet<>(Arrays.asList(DateFormat.getAvailableLocales()));
         testLocales.retainAll(Arrays.asList(NumberFormat.getAvailableLocales()));
         testLocales.add(null);
 
@@ -483,46 +480,34 @@ public class ExtendedMessageFormatTest {
 
     @Test
     public void testFailsToCreateExtendedMessageFormatTakingTwoArgumentsThrowsIllegalArgumentExceptionFive() {
-        assertThatIllegalArgumentException().isThrownBy(() -> {
-            new ExtendedMessageFormat("j/[_D9{0,\"&'+0o", new HashMap<String, FormatFactory>());
-        });
+        assertThatIllegalArgumentException().isThrownBy(() -> new ExtendedMessageFormat("j/[_D9{0,\"&'+0o", new HashMap<String, FormatFactory>()));
     }
 
     @Test
     public void testFailsToCreateExtendedMessageFormatTakingTwoArgumentsThrowsIllegalArgumentExceptionFour() {
-        assertThatIllegalArgumentException().isThrownBy(() -> {
-            new ExtendedMessageFormat("RD,nXhM{}{", new HashMap<String, FormatFactory>());
-        });
+        assertThatIllegalArgumentException().isThrownBy(() -> new ExtendedMessageFormat("RD,nXhM{}{", new HashMap<String, FormatFactory>()));
     }
 
     @Test
     public void testFailsToCreateExtendedMessageFormatTakingTwoArgumentsThrowsIllegalArgumentExceptionOne() {
-        assertThatIllegalArgumentException().isThrownBy(() -> {
-            new ExtendedMessageFormat("agdXdkR;T1{9 ^,LzXf?", new HashMap<String, FormatFactory>());
-        });
+        assertThatIllegalArgumentException().isThrownBy(() -> new ExtendedMessageFormat("agdXdkR;T1{9 ^,LzXf?", new HashMap<String, FormatFactory>()));
     }
 
     @Test
     public void testFailsToCreateExtendedMessageFormatTakingTwoArgumentsThrowsIllegalArgumentExceptionThree() {
-        assertThatIllegalArgumentException().isThrownBy(() -> {
-            new ExtendedMessageFormat("9jLh_D9{ ", new HashMap<String, FormatFactory>());
-        });
+        assertThatIllegalArgumentException().isThrownBy(() -> new ExtendedMessageFormat("9jLh_D9{ ", new HashMap<String, FormatFactory>()));
     }
 
-    // ------------------------ Test Formats ------------------------
-
     @Test
     public void testFailsToCreateExtendedMessageFormatTakingTwoArgumentsThrowsIllegalArgumentExceptionTwo() {
-        assertThatIllegalArgumentException().isThrownBy(() -> {
-            new ExtendedMessageFormat("a5XdkR;T1{9 ,LzXf?", new HashMap<String, FormatFactory>());
-        });
+        assertThatIllegalArgumentException().isThrownBy(() -> new ExtendedMessageFormat("a5XdkR;T1{9 ,LzXf?", new HashMap<String, FormatFactory>()));
     }
 
     @Test
     public void testOverriddenBuiltinFormat() {
         final Calendar cal = Calendar.getInstance();
         cal.set(2007, Calendar.JANUARY, 23);
-        final Object[] args = new Object[] {cal.getTime()};
+        final Object[] args = {cal.getTime()};
         final Locale[] availableLocales = DateFormat.getAvailableLocales();
         final Map<String, ? extends FormatFactory> dateRegistry =
                 Collections.singletonMap("date", new OverrideShortDateFormatFactory());
