@@ -17,6 +17,7 @@
 
 package org.apache.commons.text;
 
+import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.assertj.core.api.Assertions.assertThatIllegalArgumentException;
 import static org.assertj.core.api.Assertions.assertThatNullPointerException;
 import static org.junit.jupiter.api.Assertions.assertEquals;
@@ -46,7 +47,7 @@ import org.junit.jupiter.api.TestMethodOrder;
 /**
  * Test class for {@link StringSubstitutor}.
  */
-@TestMethodOrder(MethodOrderer.Alphanumeric.class) // temp, for my sanity during dev
+@TestMethodOrder(MethodOrderer.MethodName.class) // temp, for my sanity during dev
 public class StringSubstitutorTest {
 
     private static final String ACTUAL_ANIMAL = "quick brown fox";
@@ -201,6 +202,13 @@ public class StringSubstitutorTest {
         values = null;
     }
 
+    @Test
+    public void testConstructorNullMap() {
+        final Map<String, Object> parameters = null;
+        final StringSubstitutor s = new StringSubstitutor(parameters, "prefix", "suffix");
+        assertNull(s.getStringLookup().lookup("X"));
+    }
+
     @Test
     public void testConstructorStringSubstitutor() {
         final StringSubstitutor source = new StringSubstitutor();
@@ -250,6 +258,20 @@ public class StringSubstitutorTest {
         assertEquals(expected, actual);
     }
 
+    /**
+     * Tests interpolation with weird boundary patterns.
+     */
+    @Test
+    public void testReplace_JiraText178_WeirdPatterns1() throws IOException {
+        doNotReplace("$${");
+        doNotReplace("$${a");
+        doNotReplace("$$${");
+        doNotReplace("$$${a");
+        doNotReplace("$${${a");
+        doNotReplace("${${a}"); // "${a" is not a registered variable name.
+        doNotReplace("${$${a}");
+    }
+
     /**
      * Tests interpolation with weird boundary patterns.
      */
@@ -267,20 +289,6 @@ public class StringSubstitutorTest {
         doReplace("${${a}", "$${${a}", false); // not "$${1" or "${1"
     }
 
-    /**
-     * Tests interpolation with weird boundary patterns.
-     */
-    @Test
-    public void testReplace_JiraText178_WeirdPatterns1() throws IOException {
-        doNotReplace("$${");
-        doNotReplace("$${a");
-        doNotReplace("$$${");
-        doNotReplace("$$${a");
-        doNotReplace("$${${a");
-        doNotReplace("${${a}"); // "${a" is not a registered variable name.
-        doNotReplace("${$${a}");
-    }
-
     /**
      * Tests adjacent keys.
      */
@@ -747,6 +755,28 @@ public class StringSubstitutorTest {
         assertThatNullPointerException().isThrownBy(() -> StringSubstitutor.replace(null, (Properties) null));
     }
 
+    @Test
+    public void testReplaceThrowsStringIndexOutOfBoundsException() {
+        final StringSubstitutor sub = new StringSubstitutor();
+
+        // replace(char[], int, int)
+        final char[] emptyCharArray = {};
+        // offset greater than array length
+        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(
+                () -> sub.replace(emptyCharArray, 0, 1));
+        // source != null && (offset > source.length || offset < 0)
+        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(
+                () -> sub.replace(emptyCharArray, 1, 0));
+
+        // replace(String, int, int)
+        // offset greater than source length
+        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(
+                () -> sub.replace("", 1, 1));
+        // source != null && offset >= 0 && offset <= source.length() && (length > -offset + source.length() || length < 0)
+        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(
+                () -> sub.replace("", 0, 1));
+    }
+
     /**
      * Tests replace creates output same as input.
      */
@@ -1035,6 +1065,21 @@ public class StringSubstitutorTest {
             "Hi ${user.name}, you are " + "working with ${os.name}, your home " + "directory is ${user.home}."));
     }
 
+    /**
+     * Tests interpolation with system properties.
+     */
+    @Test
+    public void testStaticReplaceSystemPropertiesWithUpdate() {
+        System.setProperty("foo", "bar1");
+        try {
+            assertEqualsCharSeq("bar1", StringSubstitutor.replaceSystemProperties("${foo}"));
+            System.setProperty("foo", "bar2");
+            assertEqualsCharSeq("bar2", StringSubstitutor.replaceSystemProperties("${foo}"));
+        } finally {
+            System.getProperties().remove("foo");
+        }
+    }
+
     /**
      * Test the replace of a properties object
      */
