@@ -21,6 +21,7 @@ import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -39,6 +40,7 @@ import java.nio.charset.Charset;
 import java.util.Arrays;
 import java.util.Locale;
 
+import org.apache.commons.io.output.NullAppendable;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.text.matcher.StringMatcher;
@@ -46,7 +48,7 @@ import org.apache.commons.text.matcher.StringMatcherFactory;
 import org.junit.jupiter.api.Test;
 
 /**
- * Unit tests for {@link TextStringBuilder}.
+ * Tests {@link TextStringBuilder}.
  */
 public class TextStringBuilderTest {
 
@@ -202,26 +204,7 @@ public class TextStringBuilderTest {
         final TextStringBuilder sb = new TextStringBuilder("1234567890");
         final StringWriter writer = new StringWriter();
         writer.append("Test");
-
-        // TODO Use Commons IO NullAppendable.INSTANCE
-        sb.appendTo(new Appendable() {
-
-            @Override
-            public Appendable append(final char c) throws IOException {
-                return this;
-            }
-
-            @Override
-            public Appendable append(final CharSequence csq) throws IOException {
-                return this;
-            }
-
-            @Override
-            public Appendable append(final CharSequence csq, final int start, final int end) throws IOException {
-                return this;
-            }
-        });
-
+        sb.appendTo(NullAppendable.INSTANCE);
         assertEquals("Test", writer.toString());
     }
 
@@ -241,7 +224,7 @@ public class TextStringBuilderTest {
     @Test
     public void testAppendToStringBuffer() throws Exception {
         final TextStringBuilder sb = new TextStringBuilder("1234567890");
-        final StringBuffer buffer = new StringBuffer("Test ");
+        final StringBuilder buffer = new StringBuilder("Test ");
 
         sb.appendTo(buffer);
 
@@ -712,9 +695,7 @@ public class TextStringBuilderTest {
 
     @Test
     public void testDeleteCharAtWithNegative() {
-        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(() -> {
-            new TextStringBuilder().deleteCharAt((-1258));
-        });
+        assertThatExceptionOfType(StringIndexOutOfBoundsException.class).isThrownBy(() -> new TextStringBuilder().deleteCharAt(-1258));
     }
 
     @Test
@@ -819,7 +800,7 @@ public class TextStringBuilderTest {
         final TextStringBuilder sb = new TextStringBuilder();
         // empty buffer
         assertEquals(0, sb.drainChars(0, 5, array, 1));
-        assertEquals(0, sb.drainChars(0, 5, new char[0], 1));
+        assertEquals(0, sb.drainChars(0, 5, ArrayUtils.EMPTY_CHAR_ARRAY, 1));
         // empty buffer, 0 length request
         assertEquals(0, sb.drainChars(5, 5, array, 1));
 
@@ -899,29 +880,42 @@ public class TextStringBuilderTest {
         assertTrue(sb.capacity() >= 40);
     }
 
+    @Test
+    public void testEnsureCapacityOutOfMemoryError() {
+        final TextStringBuilder sb = new TextStringBuilder();
+        // Should not be a NegativeArraySizeException
+        sb.ensureCapacity(Integer.MIN_VALUE);
+        sb.ensureCapacity(-1);
+        sb.ensureCapacity(0);
+        // Might fail in a CI:
+        // sb.ensureCapacity(Integer.MAX_VALUE / 2);
+        sb.ensureCapacity(10_000);
+        assertThrows(OutOfMemoryError.class, () -> sb.ensureCapacity(Integer.MAX_VALUE));
+    }
+
     @Test
     public void testEquals() {
-        final TextStringBuilder sb1 = new TextStringBuilder();
-        final TextStringBuilder sb2 = new TextStringBuilder();
+        final TextStringBuilder sb1 = new TextStringBuilder(50);
+        final TextStringBuilder sb2 = new TextStringBuilder(100);
         assertTrue(sb1.equals(sb2));
         assertTrue(sb1.equals(sb1));
         assertTrue(sb2.equals(sb2));
-        assertTrue(sb1.equals((Object) sb2));
+        assertEquals(sb1, sb2);
 
         sb1.append("abc");
         assertFalse(sb1.equals(sb2));
-        assertFalse(sb1.equals((Object) sb2));
+        assertNotEquals(sb1, sb2);
 
         sb2.append("ABC");
         assertFalse(sb1.equals(sb2));
-        assertFalse(sb1.equals((Object) sb2));
+        assertNotEquals(sb1, sb2);
 
         sb2.set("abc");
         assertTrue(sb1.equals(sb2));
-        assertTrue(sb1.equals((Object) sb2));
+        assertEquals(sb1, sb2);
 
-        assertFalse(sb1.equals(Integer.valueOf(1)));
-        assertFalse(sb1.equals("abc"));
+        assertNotEquals(sb1, Integer.valueOf(1));
+        assertNotEquals("abc", sb1);
     }
 
     @Test
@@ -1058,15 +1052,28 @@ public class TextStringBuilderTest {
         final TextStringBuilder sb = new TextStringBuilder();
         final int hc1a = sb.hashCode();
         final int hc1b = sb.hashCode();
-        final int emptyHc = Arrays.hashCode(sb.getBuffer());
-        assertEquals(emptyHc, hc1a);
         assertEquals(hc1a, hc1b);
 
+        // following TEXT-211 : the hashcode of the buffer may not be equals to the hashcode of the TextStringBuilder itself
+        final int emptyHc = Arrays.hashCode(sb.getBuffer());
+        assertNotEquals(emptyHc, hc1a);
+
         sb.append("abc");
         final int hc2a = sb.hashCode();
         final int hc2b = sb.hashCode();
-        assertTrue(hc2a != emptyHc);
         assertEquals(hc2a, hc2b);
+
+        final TextStringBuilder sb2 = new TextStringBuilder(100);
+        final TextStringBuilder sb3 = new TextStringBuilder(10);
+        final int hc2 = sb2.hashCode();
+        final int hc3 = sb3.hashCode();
+        assertEquals(hc2, hc3);
+
+        sb2.append("abc");
+        sb3.append("abc");
+        final int hc2b2 = sb2.hashCode();
+        final int hc3b2 = sb3.hashCode();
+        assertEquals(hc2b2, hc3b2);
     }
 
     @Test
